@@ -573,6 +573,7 @@ class fMMS_GUI(hildon.Program):
 		textview = gtk.TextView()
 		textview.set_editable(False)
 		textview.set_cursor_visible(False)
+		textview.set_wrap_mode(gtk.WRAP_WORD)
 		textbuffer = gtk.TextBuffer()
 		path = self._mmsdir + filename
 		filelist = os.listdir(path)
@@ -583,6 +584,7 @@ class fMMS_GUI(hildon.Program):
 			isImage = False
 			try:
 				filetype = mimetypes.guess_type(fnpath)[0]
+				print "filetype:", filetype
 				if filetype != None:
 					if filetype.startswith("image"):
 						isImage = True
@@ -606,7 +608,7 @@ class fMMS_GUI(hildon.Program):
 				ebox.tap_and_hold_setup(menu)
 				#ebox.connect('tap-and-hold', self.mms_img_clicked)
 				container.add(ebox)
-			elif isText:
+			elif isText or ext.startswith(".txt"):
 				fp = open(path + "/" + fname, 'r')
 				contents = fp.read()
 				fp.close()
