@@ -205,7 +205,7 @@ class PushHandler:
 				
 			#headers = {'x-wap-profile': 'http://mms.frals.se/n900.rdf'}
 			#User-Agent: NokiaN95/11.0.026; Series60/3.1 Profile/MIDP-2.0 Configuration/CLDC-1.1 
-			headers = {'User-Agent' : 'Nokia RX-51/N900', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf', 'Profile' : 'http://mms.frals.se/n900.rdf'}
+			headers = {'User-Agent' : 'NokiaN95/11.0.026; Series60/3.1 Profile/MIDP-2.0 Configuration/CLDC-1.1', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
 			req = urllib2.Request(location, headers=headers)
 			mmsdata = urllib2.urlopen(req)
 			try:
@@ -376,7 +376,7 @@ class MMSSender:
 		### END TEMP CODE ###
 		
 		#User-Agent: NokiaN95/11.0.026; Series60/3.1 Profile/MIDP-2.0 Configuration/CLDC-1.1 
-		headers = {'Content-Type':'application/vnd.wap.mms-message', 'User-Agent' : 'Nokia RX-51/N900', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf', 'Profile' : 'http://mms.frals.se/n900.rdf'}
+		headers = {'Content-Type':'application/vnd.wap.mms-message', 'User-Agent' : 'NokiaN95/11.0.026; Series60/3.1 Profile/MIDP-2.0 Configuration/CLDC-1.1', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
 		#headers = {'Content-Type':'application/vnd.wap.mms-message'}
 		if proxyurl == "" or proxyurl == None:
 			print "connecting without proxy"
